@@ -100,8 +100,8 @@ class CustomForm extends Form
         if ($start > $end) {
             $absoluteRangeParameters = TimeRangePickerTools::getAbsoluteRangeParameters();
             $this->getRedirectUrl()->getParams()
-                ->set($absoluteRangeParameters['start'], $end)
-                ->set($absoluteRangeParameters['end'], $start);
+                ->set($absoluteRangeParameters['start'], (string) $end)
+                ->set($absoluteRangeParameters['end'], (string) $start);
         }
 
         $this->getRedirectUrl()->remove(TimeRangePickerTools::getRelativeRangeParameter());
@@ -126,6 +126,9 @@ class CustomForm extends Form
             ]);
         }
 
+        assert(isset($elementDecorators), '$elementDecorators not initialized in the loop');
+        assert(isset($element), '$element not initialized in the loop');
+
         $decorators = [];
         foreach ($elementDecorators as $key => $decorator) {
             if ($key === 'Zend_Form_Decorator_ViewHelper') {
